changeset 70562:e2bd086e6902

(Vmac_service_selection) [MAC_OSX]: Rename from Vmac_services_selection. All uses changed. (mac_store_service_event): Rename from mac_store_services_event in extern and calls.
author YAMAMOTO Mitsuharu <mituharu@math.s.chiba-u.ac.jp>
date Wed, 10 May 2006 08:24:09 +0000
parents 083b25be83bd
children fc3c18e2c3b9
files src/macselect.c
diffstat 1 files changed, 10 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/src/macselect.c	Wed May 10 08:23:45 2006 +0000
+++ b/src/macselect.c	Wed May 10 08:24:09 2006 +0000
@@ -101,7 +101,7 @@
 
 #ifdef MAC_OSX
 /* Selection name for communication via Services menu.  */
-static Lisp_Object Vmac_services_selection;
+static Lisp_Object Vmac_service_selection;
 #endif
 
 /* Get a reference to the scrap corresponding to the symbol SYM.  The
@@ -1349,7 +1349,7 @@
 				  GetEventTypeCount (specs), specs, NULL, NULL);
 }
 
-extern OSStatus mac_store_services_event P_ ((EventRef));
+extern OSStatus mac_store_service_event P_ ((EventRef));
 
 static OSStatus
 copy_scrap_flavor_data (from_scrap, to_scrap, flavor_type)
@@ -1406,12 +1406,12 @@
   Lisp_Object rest;
   ScrapFlavorType flavor_type;
 
   /* Check if Vmac_services_selection is a valid selection that has a
      corresponding scrap.  */
-  if (!SYMBOLP (Vmac_services_selection))
+  if (!SYMBOLP (Vmac_service_selection))
     err = eventNotHandledErr;
   else
-    err = get_scrap_from_symbol (Vmac_services_selection, 0, &cur_scrap);
+    err = get_scrap_from_symbol (Vmac_service_selection, 0, &cur_scrap);
   if (!(err == noErr && cur_scrap))
     return eventNotHandledErr;
 
@@ -1448,7 +1448,7 @@
       if (err != noErr)
 	break;
 
-      if (NILP (Fx_selection_owner_p (Vmac_services_selection)))
+      if (NILP (Fx_selection_owner_p (Vmac_service_selection)))
 	break;
       else
 	goto copy_all_flavors;
@@ -1458,7 +1458,7 @@
 			       typeScrapRef, NULL,
 			       sizeof (ScrapRef), NULL, &specific_scrap);
       if (err != noErr
-	  || NILP (Fx_selection_owner_p (Vmac_services_selection)))
+	  || NILP (Fx_selection_owner_p (Vmac_service_selection)))
 	{
 	  err = eventNotHandledErr;
 	  break;
@@ -1533,7 +1533,7 @@
 	if (!data_exists_p)
 	  err = eventNotHandledErr;
 	else
-	  err = mac_store_services_event (event);
+	  err = mac_store_service_event (event);
       }
       break;
     }
@@ -1611,9 +1611,9 @@
 #endif
 
 #ifdef MAC_OSX
-  DEFVAR_LISP ("mac-services-selection", &Vmac_services_selection,
+  DEFVAR_LISP ("mac-service-selection", &Vmac_service_selection,
 	       doc: /* Selection name for communication via Services menu.  */);
-  Vmac_services_selection = intern ("PRIMARY");
+  Vmac_service_selection = intern ("PRIMARY");
 #endif
 
   QPRIMARY   = intern ("PRIMARY");	staticpro (&QPRIMARY);
@@ -1406,12 +1406,12 @@
   ScrapFlavorType flavor_type;
 
-  /* Check if Vmac_services_selection is a valid selection that has a
+  /* Check if Vmac_service_selection is a valid selection that has a
      corresponding scrap.  */